# 设置 pip 镜像源

这是设置国内镜像源的工具，可以使用它快速切换镜像源地址。
目前支持
- 官方源
- 阿里云源
- 清华源
- 豆瓣源

#### 方式 1
```
命令行直接输入:pip-setting , 根据提示继续操作
```

#### 方式 2
命令行输入
- pip-setting -s aliyun
- pip-setting -source aliyun

支持选项
* aliyun: 阿里云源
* qinghua: 清华源
* douban: 豆瓣源
